# == Type postfix::alias
#
# Creates a new mail alias.
#
# === Parameters
#
# [*alias*]
#   (Namevar) The name of the alias being created.
#
# [*to*]
#   (Required) The email address the alias should point to.
#
# [*in*]
#   (Optional) The alias file that this alias should be added to (defaults
#   to /etc/aliases).
#
# [*order*]
#   (Optional) Number representing where this mapping should appear in the
#   alias file (defaults to '50'). 
#
# === Authors
#
# David McNicol <david@mcnicks.org>
#

define postfix::alias (
  $to,
  $in = '/etc/aliases',
  $order = '50'
) {

  # Check whether the title has to be split into an alias and file path.

  if $title =~ / in / {
    $alias = regsubst($title, '^(.*) in (.*)$', '\1')
    $target = regsubst($title, '^(.*) in (.*)$', '\2')
  } else {
    $alias = $title
    $target = $in
  }

  # Create the alias.

  concat::fragment { "${alias}_${alias_file}":
    target  => $target,
    order   => $order,
    content => "${alias}: ${to}"
  }

}
