# == Class: postfix::config
#
# Manages configuration for postfix.
#
# === Authors
#
# David McNicol <david@mcnicks.org>
#

class postfix::config (
  $admin_email,
  $alias_files
) {

  # Create concats for the alias files.

  postfix::alias_file { '/etc/aliases': }
  postfix::alias_file { $alias_files: }

  # This is called by postfix::alias_file to refresh the aliases database.

  exec { 'newaliases':
    path        => [ '/bin/', '/sbin/' , '/usr/bin/', '/usr/sbin/' ],
    command     => 'newaliases',
    refreshonly => true,
    require     => Package['postfix']
  }

  # Add standard aliases.

  postfix::alias { 'abuse':
    to    => 'postmaster',
    order => '98'
  }

  postfix::alias { 'postmaster':
    to    => 'root',
    order => '98'
  }

  postfix::alias { 'root':
    to    => $admin_email,
    order => '99'
  }

  # Create a concat for the transport file.

  concat { '/etc/postfix/transport':
    ensure_newline => true,
    warn           => true,
    force          => true,
    require        => Package['postfix'],
    notify         => Exec['postmap_transport']
  }

  exec { 'postmap_transport':
    path        => [ '/bin/', '/sbin/' , '/usr/bin/', '/usr/sbin/' ],
    command     => 'postmap /etc/postfix/transport',
    refreshonly => true,
    require     => Package['postfix']
  }

  # Create a concat for the virtual file.

  concat { '/etc/postfix/virtual':
    ensure_newline => true,
    warn           => true,
    force          => true,
    require        => Package['postfix'],
    notify         => Exec['postmap_virtual']
  }

  exec { 'postmap_virtual':
    path        => [ '/bin/', '/sbin/' , '/usr/bin/', '/usr/sbin/' ],
    command     => 'postmap /etc/postfix/virtual',
    refreshonly => true,
    require     => Package['postfix']
  }

  # Create a concat for the virtual regexp file.

  concat { '/etc/postfix/virtual_regexp':
    ensure_newline => true,
    warn           => true,
    force          => true,
    require        => Package['postfix']
  }

}
